==> haskell-wl-pprint-extras-3.5.0.5-554.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-wl-pprint-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wl-pprint-extras
version:              3.5.0.5
visibility:           public
id:                   wl-pprint-extras-3.5.0.5-EbiadCa06z64cP8akzaS3L
key:                  wl-pprint-extras-3.5.0.5-EbiadCa06z64cP8akzaS3L
license:              BSD-3-Clause
copyright:
    Copyright (C) 2011-2012 Edward A. Kmett,
    Copyright (C) 2000 Daan Leijen

maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/wl-pprint-extras/
synopsis:             A free monad based on the Wadler/Leijen pretty printer
description:          A free monad based on the Wadler/Leijen pretty printer
category:             Control, Monads, Text
abi:                  58bbc03661216e4e41bd7d8e9f5e040a
exposed:              True
exposed-modules:      Text.PrettyPrint.Free Text.PrettyPrint.Free.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/wl-pprint-extras-3.5.0.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wl-pprint-extras-3.5.0.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wl-pprint-extras-3.5.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wl-pprint-extras
hs-libraries:         HSwl-pprint-extras-3.5.0.5-EbiadCa06z64cP8akzaS3L
depends:
    base-4.18.2.1 containers-0.6.7
    semigroupoids-6.0.1-ErxGHkCkp7JG4CGTcMGRW9 text-2.0.2
    utf8-string-1.0.2-6mVuGO0K0TVHYD6zuQNk2y

haddock-interfaces:
    /usr/share/doc/haskell-wl-pprint-extras/html/wl-pprint-extras.haddock

haddock-html:         /usr/share/doc/haskell-wl-pprint-extras/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wl-pprint-extras-3.5.0.5-555-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-wl-pprint-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wl-pprint-extras
version:              3.5.0.5
visibility:           public
id:                   wl-pprint-extras-3.5.0.5-JkvCysZQ9OwEvBJ08U4yfL
key:                  wl-pprint-extras-3.5.0.5-JkvCysZQ9OwEvBJ08U4yfL
license:              BSD-3-Clause
copyright:
    Copyright (C) 2011-2012 Edward A. Kmett,
    Copyright (C) 2000 Daan Leijen

maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/wl-pprint-extras/
synopsis:             A free monad based on the Wadler/Leijen pretty printer
description:          A free monad based on the Wadler/Leijen pretty printer
category:             Control, Monads, Text
abi:                  d3e8593cabc91ae91c73a69f70dd751e
exposed:              True
exposed-modules:      Text.PrettyPrint.Free Text.PrettyPrint.Free.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/wl-pprint-extras-3.5.0.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wl-pprint-extras-3.5.0.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wl-pprint-extras-3.5.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wl-pprint-extras
hs-libraries:         HSwl-pprint-extras-3.5.0.5-JkvCysZQ9OwEvBJ08U4yfL
depends:
    base-4.18.2.1 containers-0.6.7
    semigroupoids-6.0.1-133SNw0FNd08WQLIYIjtGS text-2.0.2
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv

haddock-interfaces:
    /usr/share/doc/haskell-wl-pprint-extras/html/wl-pprint-extras.haddock

haddock-html:         /usr/share/doc/haskell-wl-pprint-extras/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
